pub fn difficulty_threshold_is_valid(
header: &Header,
network: &Network,
height: &Height,
hash: &Hash,
) -> Result<ExpandedDifficulty, BlockError>Expand description
Returns Ok(ExpandedDifficulty) if thedifficulty_threshold of header is at least as difficult as
the target difficulty limit for network (PoWLimit)
If the header difficulty threshold is invalid, returns an error containing height and hash.